"""RAG tools for database operations.

This module provides tools for Retrieval-Augmented Generation (RAG) operations
with various databases, including Neo4j integration.
"""

from langchain.agents import initialize_agent as langchain_initialize_agent
from langchain.agents.agent_types import AgentType
from langchain_groq import ChatGroq

def initialize_groq_agent(tools, api_key, model_name="llama-3.3-70b-versatile"):
    llm = ChatGroq(groq_api_key=api_key, model_name=model_name, streaming=True)
    
    return langchain_initialize_agent(
        tools, 
        llm, 
        agent=AgentType.ZERO_SHOT_REACT_DESCRIPTION, 
        verbose=True
    )

__all__ = [
    "initialize_groq_agent",
]